# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Text-Hunspell
Version:	2.16
Release:	3.%{__distinit}%{__distvers}
Summary:	Perl interface to the Hunspell library
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Text-Hunspell
Source0:	https://cpan.metacpan.org/modules/by-module/Text/Text-Hunspell-%{version}.tar.gz
Patch1:		Text-Hunspell-2.15-no-Alien.patch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc-c++
BuildRequires:	hunspell-devel >= 1.2.8
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.52
BuildRequires:	perl(ExtUtils::PkgConfig)
BuildRequires:	sed
# Module Runtime
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(vars)
# Test Suite
%if 0%{?fedora} > 23 || 0%{?rhel} > 7
BuildRequires:	glibc-langpack-en
%endif
BuildRequires:	hunspell-en
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(warnings)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
This module provides a Perl interface to the Hunspell library. This module
is to meet the need of looking up many words, one at a time, in a single
session, such as spell-checking a document in memory.

%prep
%setup -q -n Text-Hunspell-%{version}

# We don't have (nor need) Alien::Hunspell, so revert to using ExtUtils::PkgConfig
%patch -P 1

# Fix up shellbang in example
sed -i -e 's|^#!/usr/bin/env perl|#!/usr/bin/perl|' examples/basic.pl

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
LANG=en_US make test TEST_POD=1 TEST_VERBOSE=1

%files
%license LICENSE
%doc Changes README examples/
%{perl_vendorarch}/auto/Text/
%{perl_vendorarch}/Text/
%{_mandir}/man3/Text::Hunspell.3*

%changelog
* Wed May 31 2023 Paul Howarth <paul@city-fan.org> - 2.16-3
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax
- Drop support for building with ExtUtils::MakeMaker < 6.52

* Fri Jul 15 2022 Paul Howarth <paul@city-fan.org> - 2.16-1
- Update to 2.16
  - Documentation improvements (GH#16, GH#18)
  - Add LICENSE file (GH#14)

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 2.14-25
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 2.14-22
- Perl 5.34 rebuild

* Thu Jun 25 2020 Paul Howarth <paul@city-fan.org> - 2.14-19
- Perl 5.32 rebuild

* Fri May 31 2019 Paul Howarth <paul@city-fan.org> - 2.14-16
- Perl 5.30 rebuild

* Tue Nov 13 2018 Paul Howarth <paul@city-fan.org> - 2.14-14
- Rebuild for hunspell 1.7.x

* Wed Nov  7 2018 Paul Howarth <paul@city-fan.org> - 2.14-13
- Explicitly BR: glibc-langpack-en

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 2.14-11
- Perl 5.28 rebuild

* Thu Feb 15 2018 Paul Howarth <paul@city-fan.org> - 2.14-10
- Fix up shellbang in example

* Sun Aug  6 2017 Paul Howarth <paul@city-fan.org> - 2.14-8
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Tue Dec 13 2016 Paul Howarth <paul@city-fan.org> - 2.14-4
- Rebuild for hunspell 1.5.4 in Rawhide

* Tue Oct 11 2016 Paul Howarth <paul@city-fan.org> - 2.14-3
- BR: perl-generators where available
- Simplify find commands using -empty and -delete

* Fri Jan 15 2016 Paul Howarth <paul@city-fan.org> - 2.14-1
- Update to 2.14
  - No functional changes
  - Text::Hunspell now depends on Alien::Hunspell version 0.04, and should
    finally compile nicely on Win32 platform
- Update patches as needed

* Mon Jan 11 2016 Paul Howarth <paul@city-fan.org> - 2.13-1
- Update to 2.13
  - Win32 build support added
- Update patches as needed

* Mon Dec 21 2015 Paul Howarth <paul@city-fan.org> - 2.12-1
- Update to 2.12
  - Replaced ExtUtils::PkgConfig with Alien::Hunspell
- Explicitly BR: perl-devel, needed for EXTERN.h
- We don't have (nor need) Alien::Hunspell, so revert to using
  ExtUtils::PkgConfig

* Wed Jun 17 2015 Paul Howarth <paul@city-fan.org> - 2.11-2
- Perl 5.22 rebuild

* Wed May 13 2015 Paul Howarth <paul@city-fan.org> - 2.11-1
- Update to 2.11
  - Fix compilation on non-gcc based systems (CPAN RT#99810)
  - Minor clean-ups
  - No functional changes
- Update patch to support building with ExtUtils::MakeMaker < 6.52

* Thu Mar 26 2015 Paul Howarth <paul@city-fan.org> - 2.10-1
- Update to 2.10
  - Fix ExtUtils::PkgConfig usage in metadata and Makefile.PL
    (http://github.com/cosimo/perl5-text-hunspell/issues/5)
- Add patch to support building with ExtUtils::MakeMaker < 6.52

* Mon Oct 20 2014 Paul Howarth <paul@city-fan.org> - 2.09-1
- Update to 2.09
  - Use ExtUtils::PkgConfig to find libhunspell (CPAN RT#99548)
- Classify buildreqs by usage

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 2.08-6
- Perl 5.20 rebuild

* Tue Jul 16 2013 Paul Howarth <paul@city-fan.org> - 2.08-2
- Perl 5.18 rebuild

* Thu May  2 2013 Paul Howarth <paul@city-fan.org> - 2.08-1
- Update to 2.08
  - Improved main POD documentation for Hunspell.pm (CPAN RT#84964)

* Tue Mar 26 2013 Paul Howarth <paul@city-fan.org> - 2.07-1
- Update to 2.07
  - DEPRECATED the delete() method and implemented proper object handles in
    the hunspell XS glue so that multiple speller objects can coexist
    (CPAN RT#84054)

* Sat Mar  9 2013 Paul Howarth <paul@city-fan.org> - 2.06-1
- Update to 2.06
  - Implemented new add_dic() function from hunspell API (CPAN RT#83765)

* Fri Sep 21 2012 Paul Howarth <paul@city-fan.org> - 2.05-1
- Update to 2.05 (fix pod encoding - CPAN RT#79630)
- Drop upstreamed pod encoding patch

* Fri Sep 21 2012 Paul Howarth <paul@city-fan.org> - 2.04-1
- Update to 2.04 (specify pod encoding to placate pod test - CPAN RT#79630)
- Update pod encoding patch

* Sat Jun 23 2012 Paul Howarth <paul@city-fan.org> - 2.03-4
- BR: perl(Data::Dumper) and perl(File::Spec)
- Don't need to remove empty directories from the buildroot
- Drop %%defattr, redundant since rpm 4.4

* Sat Jun 25 2011 Paul Howarth <paul@city-fan.org> - 2.03-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 24 2011 Paul Howarth <paul@city-fan.org> - 2.03-1
- Update to 2.03 (fixed use of "qw()" as parenthesis in inc/Devel/CheckLib.pm
  because it's deprecated in perl 5.14)

* Wed May 25 2011 Paul Howarth <paul@city-fan.org> - 2.02-2
- Rebuild for hunspell-1.3 in Rawhide
- Nobody else likes macros for commands
- Use DESTDIR rather than PERL_INSTALL_ROOT
- Use %%{_fixperms} macro instead of our own chmod incantation

* Sun Oct 24 2010 Paul Howarth <paul@city-fan.org> - 2.02-1
- Update to 2.02 (added an explicit warning if the unversioned libhunspell.so
  symlink or library is not found)

* Fri Oct  1 2010 Paul Howarth <paul@city-fan.org> - 2.01-2
- Rebuild for gcc bug (#634757)

* Wed Sep  8 2010 Paul Howarth <paul@city-fan.org> - 2.01-1
- Initial RPM version
